Manifest File

## DLP Phase Light Modulator Python Library Manifest

#### 2025-07-05

#### Manifest ID - SRAS00012573

#### Legend

(explanation of the fields in the Manifest Table below)

Software Name | The name of the application or file
Version | Version of the application or file
License Type | Type of license(s) under which TI will be providing software to the licensee (e.g. BSD-3-Clause, GPL-2.0, TI TSPA License, TI Commercial License). The license could be under Commercial terms or Open Source. See Open Source Reference License Disclaimer in the Disclaimers Section. Whenever possible, TI will use an SPDX Short Identifier for an Open Source License. TI Commercial license terms are not usually included in the manifest and are conveyed through a variety of means such as a clickwrap license upon install, a signed license agreement and so forth.
Location | The directory name and path on the media or a specific file where the Software is located. Typically fully qualified path names are not used and instead the relevant top level directory of the application is given. A notation often used in the manifests is [as installed]/directory/*. Note that the asterisk implies that all files under that directory are licensed as the License Type field denotes. Any exceptions to this will generally be denoted as [as installed]/directory/* except as noted below which means as shown in subsequent rows of the manifest.
Delivered As | This field will either be “Source”, “Binary” or “Source and Binary” and is the primary form the content of the Software is delivered in. If the Software is delivered in an archive format, this field applies to the contents of the archive. If the word Limited is used with Source, as in “Limited Source” or “Limited Source and Binary” then only portions of the Source for the application are provided.
Modified by TI | This field will either be “Yes” or “No”. A “Yes” means TI has made changes to the Software. A “No” means TI has not made any changes. Note: This field is not applicable for Software “Obtained from” TI.
Obtained from | This field specifies from where or from whom TI obtained the Software. It may be a URL to an Open Source site, a 3rd party licensor, or TI. See Links Disclaimer in the Disclaimers Section.

### Disclaimers

#### Export Control Classification Number (ECCN)

Any use of ECCNs listed in the Manifest is at the user’s risk and without recourse to TI. Your company, as the exporter of record, is responsible for determining the correct classification of any item at the time of export. Any export classification by TI of Software is for TI’s internal use only and shall not be construed as a representation or warranty regarding the proper export classification for such Software or whether an export license or other documentation is required for exporting such Software

#### Links in the Manifest

Any links appearing on this Manifest (for example in the “Obtained from” field) were verified at the time the Manifest was created. TI makes no guarantee that any listed links will remain active in the future.

#### Open Source License References

Your company is responsible for confirming the applicable license terms for any open source Software listed in this Manifest that was not “Obtained from” TI. Any open source license specified in this Manifest for Software that was not “Obtained from” TI is for TI’s internal use only and shall not be construed as a representation or warranty regarding the proper open source license terms for such Software.

#### Export Information

ECCN for Software included in this release:

Publicly Available

## DLP Phase Light Modulator Python Library Manifest Table

See the Legend above for a description of these columns.

Software Name | Version | License Type | Delivered As | Modified by TI |  |
DLP Phase Light Modulator Python Library | N/A | MIT | Source | N/A | Location | https://github.com/TexasInstruments-Sandbox/ti-phase-light-modulator
Obtained from | Texas Instruments

#### Credits

#### Licenses

## DLP Phase Light Modulator Python Library Licenses

MIT License
Copyright (c) 2025 Texas Instruments
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.